local shader = love.graphics.newShader[[

extern mat3 tf;
extern Image bgi;
extern vec2 bgsize;

vec4 effect(vec4 col, Image texture, vec2 texpos, vec2 origscrpos)
{
  // Apply current transform to origscrpos to get scrpos
  vec2 scrpos = (tf*vec3(origscrpos, 1)).xy;

  // Grab colour from texture at current position
  vec4 texc = Texel(texture, texpos);

  // Grab colour from background based on transformed screen position
  vec4 bgc = Texel(bgi, vec2(scrpos.x/bgsize.x,
                             scrpos.y/bgsize.y));

  // Example effect: lighten only (without respecting alpha)
  return vec4(max(texc, bgc));
}

]]

local img1 = love.graphics.newImage('image1.jpg') -- background
local img2 = love.graphics.newImage('image2.png') -- sprite

-- In this demo, we only need to do this once. YMMV.
shader:send('bgsize', {img1:getDimensions()})

local rot
local translationx
local translationy
local t = 0
local shearx, sheary, scale
local img2x,img2y

function love.update(dt)
  t = t + dt
  rot = math.sin(t * 0.1) * math.pi * 2
  img2x = (math.sin(t * 0.7) + 1)/2 * (img1:getWidth() - img2:getWidth())
  img2y = (math.sin(t * 0.9) + 1)/2 * (img1:getHeight() - img2:getHeight())
  shearx = math.sin(t * 1.1) * 0.3
  sheary = math.sin(t * 1.3) * 0.2
  transx = math.sin(t * 1.7) * love.graphics.getWidth()/8
  transy = math.sin(t * 1.9) * love.graphics.getHeight()/6
  scale = (math.sin(t * 0.8) + 4)/8
end

local tf = {0,0,0,0,0,0,0,0,1}
local toggle = true

function love.draw()
  -- Apply some transformations
  love.graphics.translate(transx, transy)
  love.graphics.translate(love.graphics.getWidth()/2, love.graphics.getHeight()/2)
  love.graphics.rotate(rot)
  love.graphics.scale(scale,scale)
  love.graphics.shear(shearx,sheary)
  love.graphics.translate(-love.graphics.getWidth()/2,-love.graphics.getHeight()/2)

  -- Draw background
  love.graphics.draw(img1)

  if toggle then
    local ox, oy = love.graphics.inverseTransformPoint(0, 0)
    local ix, iy = love.graphics.inverseTransformPoint(1, 0)
    local jx, jy = love.graphics.inverseTransformPoint(0, 1)
    ix, iy = ix - ox, iy - oy
    jx, jy = jx - ox, jy - oy
    tf[1] = ix; tf[2] = jx; tf[3] = ox; tf[4] = iy; tf[5] = jy; tf[6] = oy
    shader:send('tf', tf)
    shader:send('bgi', img1)
    love.graphics.setShader(shader)
  end

  love.graphics.draw(img2, img2x, img2y)
  love.graphics.setShader()
end

function love.keypressed(k)
  if k == "escape" then love.event.quit() end
  if k == "space" then toggle = not toggle end
end
